# _*_ coding: utf-8 _*_
#
# hspylib-clitt v0.9.43
#
# Package: main.clitt.core.tui
"""Package initialization."""

__all__ = [
  'mchoose', 
  'mdashboard', 
  'menu', 
  'minput', 
  'mselect', 
  'table', 
  'tui_application', 
  'tui_component', 
  'tui_preferences', 
  'tui_screen'
]
__version__ = '0.9.43'
